function lipconfig(values)
% LIPCONFIG   - Configuration function for LIPSOL.
%            lipconfig sets the default configuration.
%            lipconfig(values) resets the three configuration
%            parameters to the value given in the vector VALUES. 
%            The default configuration values are [16 8 0].
%            lipconfig([]) displays the current configuration

% Yin Zhang, July, 1995
% Department of Mathematics and Statistics
% University of Maryland  Baltimore County

global OUTFID
global CACHE_SIZE  % cache size in kbytes, default = 16
global LOOP_LEVEL  % loop unrolling level, default = 8
global MONITOR_ON  % 0 = Off,  1 = On,     default = 0
global PROBDIR     % directories containing problems

PROBDIR = str2mat([]);  % Do not change this line
PROBDIR = str2mat(PROBDIR,'../matdir');
PROBDIR = str2mat(PROBDIR,'../mpsdir');
PROBDIR = str2mat(PROBDIR,'../lppdir');
%PROBDIR = str2mat(PROBDIR,'.../.../LPs/netlib');
%PROBDIR = str2mat(PROBDIR,'.../.../LPs/private');

if nargin == 0 
  CACHE_SIZE = 16;
  LOOP_LEVEL = 8;
  MONITOR_ON = 0;
  return;
end;

if nargin == 1 
  if length(values) == 3  
     CACHE_SIZE = values(1);
     LOOP_LEVEL = values(2);
     MONITOR_ON = values(3);
     msg = '\n Config parameters changed to:\n';
  else
     msg = '\n Config parameters unchanged:\n';
  end;
  if isempty(OUTFID) OUTFID = 1; end; fprintf(OUTFID,msg);
  fprintf(OUTFID,'   Computer cache size   : %i\n',CACHE_SIZE);
  fprintf(OUTFID,'   Loop unrolling level  : %i\n',LOOP_LEVEL);
  fprintf(OUTFID,'   LIPSOL graphic monitor: %i\n\n',MONITOR_ON);
end
